==> libgnomedb-1.3.1.tar.bz2: libgnomedb-1.3.1/libgnomedb/handlers/gnome-db-handler-none.h <==
/* gnome-db-handler-none.h
 *
 * Copyright (C) 2003 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_HANDLER_NONE__
#define __GNOME_DB_HANDLER_NONE__

#include <libgnomedb/gnome-db-base.h>
#include <libgnomedb/gnome-db-server.h>
#include <libgnomedb/gnome-db-data-handler.h>

G_BEGIN_DECLS

#define GNOME_DB_HANDLER_NONE_TYPE          (gnome_db_handler_none_get_type())
#define GNOME_DB_HANDLER_NONE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_none_get_type(), GnomeDbHandlerNone)
#define GNOME_DB_HANDLER_NONE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_none_get_type (), GnomeDbHandlerNoneClass)
#define IS_GNOME_DB_HANDLER_NONE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_none_get_type ())


typedef struct _GnomeDbHandlerNone      GnomeDbHandlerNone;
typedef struct _GnomeDbHandlerNoneClass GnomeDbHandlerNoneClass;
typedef struct _GnomeDbHandlerNonePriv  GnomeDbHandlerNonePriv;


/* struct for the object's data */
struct _GnomeDbHandlerNone
{
	GnomeDbBase                object;

	GnomeDbHandlerNonePriv  *priv;
};

/* struct for the object's class */
struct _GnomeDbHandlerNoneClass
{
	GnomeDbBaseClass            parent_class;
};


guint           gnome_db_handler_none_get_type      (void);
GObject        *gnome_db_handler_none_new           (GnomeDbServer *srv);

G_END_DECLS

#endif

==> libgnomedb-1.3.4.tar.bz2: libgnomedb-1.3.4/libgnomedb/handlers/gnome-db-handler-none.h <==
/* gnome-db-handler-none.h
 *
 * Copyright (C) 2003 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_HANDLER_NONE__
#define __GNOME_DB_HANDLER_NONE__

#include <libgnomedb/gnome-db-base.h>
#include <libgnomedb/gnome-db-server.h>
#include <libgnomedb/gnome-db-data-handler.h>

G_BEGIN_DECLS

#define GNOME_DB_HANDLER_NONE_TYPE          (gnome_db_handler_none_get_type())
#define GNOME_DB_HANDLER_NONE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_none_get_type(), GnomeDbHandlerNone)
#define GNOME_DB_HANDLER_NONE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_none_get_type (), GnomeDbHandlerNoneClass)
#define IS_GNOME_DB_HANDLER_NONE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_none_get_type ())


typedef struct _GnomeDbHandlerNone      GnomeDbHandlerNone;
typedef struct _GnomeDbHandlerNoneClass GnomeDbHandlerNoneClass;
typedef struct _GnomeDbHandlerNonePriv  GnomeDbHandlerNonePriv;


/* struct for the object's data */
struct _GnomeDbHandlerNone
{
	GnomeDbBase                object;

	GnomeDbHandlerNonePriv  *priv;
};

/* struct for the object's class */
struct _GnomeDbHandlerNoneClass
{
	GnomeDbBaseClass            parent_class;
};


GType           gnome_db_handler_none_get_type      (void);
GObject        *gnome_db_handler_none_new           (GnomeDbServer *srv);

G_END_DECLS

#endif
